==> media-api-1.0.24.4-zfz-20170204.041300-1-sources.jar: cn/com/duiba/tuia/media/api/dto/rsp/RspActivityDto.java <==
package cn.com.duiba.tuia.media.api.dto.rsp;

import java.io.Serializable;
import java.util.List;

/**
 * Function: RspActivityDto
 *
 * @author xuyenan
 * @createTime 2016/10/24
 */
public class RspActivityDto implements Serializable {

    private static final long                 serialVersionUID = 98764557625344564L;

    /** 活动ID */
    private Long                              id;

    /** 活动名称 */
    private String                            name;

    /** 活动类型 */
    private Integer                           type;

    /** 活动类型名称 */
    private String                            typeName;

    /** 活动状态 */
    private String                            status;

    /** 广告位素材规格列表 */
    private List<Long>                        msIdList;

    /** 定向模式： 0仅投放定向列表，1优先投放定向列表 */
    private Integer                           directAdvertMode;

    /** 是否定向广告券 */
    private Integer                           isDirectAdvert;

    /** 是否定向媒体 */
    private Integer                           isDirectMedia;

    /** 活动是否开启 */
    private Integer                           isEnable;

    /** 是否已发布活动计划 */
    private Integer                           isPublish;

    /** 规格内容列表 */
    private List<RspMaterialSpecificationDto> msList;

    /** 活动计划ID */
    private Long                              planId;

    /** 素材数量 */
    private Integer                           itemContentAmount;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public String getTypeName() {
        return typeName;
    }

    public void setTypeName(String typeName) {
        this.typeName = typeName;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public List<Long> getMsIdList() {
        return msIdList;
    }

    public void setMsIdList(List<Long> msIdList) {
        this.msIdList = msIdList;
    }

    public Integer getDirectAdvertMode() {
        return directAdvertMode;
    }

    public void setDirectAdvertMode(Integer directAdvertMode) {
        this.directAdvertMode = directAdvertMode;
    }

    public Integer getIsDirectAdvert() {
        return isDirectAdvert;
    }

    public void setIsDirectAdvert(Integer isDirectAdvert) {
        this.isDirectAdvert = isDirectAdvert;
    }

    public Integer getIsDirectMedia() {
        return isDirectMedia;
    }

    public void setIsDirectMedia(Integer isDirectMedia) {
        this.isDirectMedia = isDirectMedia;
    }

    public Integer getIsEnable() {
        return isEnable;
    }

    public void setIsEnable(Integer isEnable) {
        this.isEnable = isEnable;
    }

    public Integer getIsPublish() {
        return isPublish;
    }

    public void setIsPublish(Integer isPublish) {
        this.isPublish = isPublish;
    }

    public List<RspMaterialSpecificationDto> getMsList() {
        return msList;
    }

    public void setMsList(List<RspMaterialSpecificationDto> msList) {
        this.msList = msList;
    }

    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }

    public Integer getItemContentAmount() {
        return itemContentAmount;
    }

    public void setItemContentAmount(Integer itemContentAmount) {
        this.itemContentAmount = itemContentAmount;
    }
}

==> media-api-1.0.27-zfz-20170222.020055-1-sources.jar: cn/com/duiba/tuia/media/api/dto/rsp/RspActivityDto.java <==
package cn.com.duiba.tuia.media.api.dto.rsp;

import java.io.Serializable;
import java.util.List;

/**
 * Function: RspActivityDto
 *
 * @author xuyenan
 * @createTime 2016/10/24
 */
public class RspActivityDto implements Serializable {

    private static final long                 serialVersionUID = 98764557625344564L;

    /** 活动开启状态 */
    public static final int                   ACT_ENABLE       = 1;

    /** 活动关闭状态 */
    public static final int                   ACT_UNABLE       = 0;

    /** 活动已经定向给指定媒体 */
    public static final boolean               ACT_BINDED       = true;

    /** 活动未定向给指定媒体 */
    public static final boolean               ACT_UNBIND       = false;

    /** 活动ID */
    private Long                              id;

    /** 活动名称 */
    private String                            name;

    /** 活动类型 */
    private Integer                           type;

    /** 活动类型名称 */
    private String                            typeName;

    /** 活动状态 */
    private String                            status;

    /** 广告位素材规格列表 */
    private List<Long>                        msIdList;

    /** 定向模式： 0仅投放定向列表，1优先投放定向列表 */
    private Integer                           directAdvertMode;

    /** 是否定向广告券 */
    private Integer                           isDirectAdvert;

    /** 是否定向媒体 */
    private Integer                           isDirectMedia;

    /** 活动是否开启 */
    private Integer                           isEnable;

    /** 是否已发布活动计划 */
    private Integer                           isPublish;

    /** 规格内容列表 */
    private List<RspMaterialSpecificationDto> msList;

    /** 活动计划ID */
    private Long                              planId;

    /** 素材数量 */
    private Integer                           itemContentAmount;

    /** 该活动是否已经定向媒体 */
    private Boolean                           isBinded;

    /**
     * isBinded.
     *
     * @return the isBinded
     * @since JDK 1.6
     */
    public Boolean getIsBinded() {
        return isBinded;
    }

    /**
     * isBinded.
     *
     * @param isBinded the isBinded to set
     * @since JDK 1.6
     */
    public void setIsBinded(Boolean isBinded) {
        this.isBinded = isBinded;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public String getTypeName() {
        return typeName;
    }

    public void setTypeName(String typeName) {
        this.typeName = typeName;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public List<Long> getMsIdList() {
        return msIdList;
    }

    public void setMsIdList(List<Long> msIdList) {
        this.msIdList = msIdList;
    }

    public Integer getDirectAdvertMode() {
        return directAdvertMode;
    }

    public void setDirectAdvertMode(Integer directAdvertMode) {
        this.directAdvertMode = directAdvertMode;
    }

    public Integer getIsDirectAdvert() {
        return isDirectAdvert;
    }

    public void setIsDirectAdvert(Integer isDirectAdvert) {
        this.isDirectAdvert = isDirectAdvert;
    }

    public Integer getIsDirectMedia() {
        return isDirectMedia;
    }

    public void setIsDirectMedia(Integer isDirectMedia) {
        this.isDirectMedia = isDirectMedia;
    }

    public Integer getIsEnable() {
        return isEnable;
    }

    public void setIsEnable(Integer isEnable) {
        this.isEnable = isEnable;
    }

    public Integer getIsPublish() {
        return isPublish;
    }

    public void setIsPublish(Integer isPublish) {
        this.isPublish = isPublish;
    }

    public List<RspMaterialSpecificationDto> getMsList() {
        return msList;
    }

    public void setMsList(List<RspMaterialSpecificationDto> msList) {
        this.msList = msList;
    }

    public Long getPlanId() {
        return planId;
    }

    public void setPlanId(Long planId) {
        this.planId = planId;
    }

    public Integer getItemContentAmount() {
        return itemContentAmount;
    }

    public void setItemContentAmount(Integer itemContentAmount) {
        this.itemContentAmount = itemContentAmount;
    }
}
